/**********************************************************************
 * Class TableINSTITUTION
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-03-15 Commented and ported to Apache Maven 
 * Default values for all attributes (-1 for all numeric ones) 2011-04-08
 * Created on 2010-07-27 by Karaca Kocer
 ********************************************************************/

package org.nbnResolving.database.model;

import java.util.Date;

/**
 * A simple class modeling 1:1 the existing Sybase
 * RDBMS table INSTITUTION in epicur database.
 * For more information please see the database model.
 * 
 * @author Kadir Karaca Kocer
 */

public class TableINSTITUTION {
	int     institution_id = -1; //unique id of this institution
	String  name = "Undefined Institution"; //
	String  street = null;
	String  office_box = null;
	String  zip = null;
	String  city = null;
	String  country = null;
	String  sign = null;
	String  checksum_algorithm = null;
	boolean check_checksum = false;
	Date    created = new Date();       //date this record created. Default: NOW!
	Date    last_modified = new Date(); //date this record last modified
	String  comment = null;        //human readable comments about this record
	
	/**
	 * Prints object state in a human friendly way
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		String ret = "\nInformation about INSTITUTION \n";
		ret = ret + "Institution Id ..: " + this.institution_id + "\n";
		ret = ret + "Name ............: " + this.name + "\n";
		
		ret = ret + "Street ..........: ";
		if (this.street != null) ret = ret + this.street + "\n"; else ret = ret + " --\n";
		
		ret = ret + "Office box ......: ";
		if (this.office_box != null) ret = ret + this.office_box + "\n"; else ret = ret + " --\n";
		
		ret = ret + "Zip .............: ";
		if (this.zip != null) ret = ret + this.zip + "\n"; else ret = ret + " --\n";
		
		ret = ret + "City ............: ";
		if (this.city != null) ret = ret + this.city + "\n"; else ret = ret + " --\n";
		
		ret = ret + "Country .........: ";
		if (this.country != null) ret = ret + this.country + "\n"; else ret = ret + " --\n";
		
		ret = ret + "Sign ............: ";
		if (this.sign != null) ret = ret + this.sign + "\n"; else ret = ret + " --\n";		

		ret = ret + "Checksum type ...: ";
		if (this.checksum_algorithm != null) ret = ret + this.checksum_algorithm + "\n"; else ret = ret + " --\n";
		
		ret = ret + "Check checksum ..: " + this.check_checksum + "\n";		
		ret = ret + "Created .........: " + this.created + "\n";
		ret = ret + "Last modified ...: " + this.last_modified + "\n";
		
		if (this.comment != null) {
			ret = ret + "Comments:\n\t" + this.comment + "\n";
		} else {
			ret = ret + "There are no comments saved for this INSTITUTION\n";
		}
		
		return ret;
	}

	/**
	 * @return the institution_id
	 */
	public int getInstitution_id() {
		return this.institution_id;
	}
	/**
	 * @param institution_id the institution_id to set
	 */
	public void setInstitution_id(int institution_id) {
		this.institution_id = institution_id;
	}
	/**
	 * @return the name
	 */
	public String getName() {
		return this.name;
	}
	/**
	 * @param name the name to set
	 */
	public void setName(String name) {
		this.name = name;
	}
	/**
	 * @return the street
	 */
	public String getStreet() {
		return this.street;
	}
	/**
	 * @param street the street to set
	 */
	public void setStreet(String street) {
		this.street = street;
	}
	/**
	 * @return the office_box
	 */
	public String getOffice_box() {
		return this.office_box;
	}
	/**
	 * @param office_box the office_box to set
	 */
	public void setOffice_box(String office_box) {
		this.office_box = office_box;
	}
	/**
	 * @return the zip
	 */
	public String getZip() {
		return this.zip;
	}
	/**
	 * @param zip the zip to set
	 */
	public void setZip(String zip) {
		this.zip = zip;
	}
	/**
	 * @return the city
	 */
	public String getCity() {
		return this.city;
	}
	/**
	 * @param city the city to set
	 */
	public void setCity(String city) {
		this.city = city;
	}
	/**
	 * @return the country
	 */
	public String getCountry() {
		return this.country;
	}
	/**
	 * @param country the country to set
	 */
	public void setCountry(String country) {
		this.country = country;
	}
	/**
	 * @return the sign
	 */
	public String getSign() {
		return this.sign;
	}
	/**
	 * @param sign the sign to set
	 */
	public void setSign(String sign) {
		this.sign = sign;
	}
	/**
	 * @return the checksum_algorithm
	 */
	public String getChecksum_algorithm() {
		return this.checksum_algorithm;
	}
	/**
	 * @param checksum_algorithm the checksum_algorithm to set
	 */
	public void setChecksum_algorithm(String checksum_algorithm) {
		this.checksum_algorithm = checksum_algorithm;
	}
	/**
	 * @return the check_checksum
	 */
	public boolean isCheck_checksum() {
		return this.check_checksum;
	}
	/**
	 * @param check_checksum the check_checksum to set
	 */
	public void setCheck_checksum(boolean check_checksum) {
		this.check_checksum = check_checksum;
	}
	/**
	 * @return the created
	 */
	public Date getCreated() {
		return this.created;
	}
	/**
	 * @param created the created to set
	 */
	public void setCreated(Date created) {
		this.created = created;
	}
	/**
	 * @return the last_modified
	 */
	public Date getLast_modified() {
		return this.last_modified;
	}
	/**
	 * @param last_modified the last_modified to set
	 */
	public void setLast_modified(Date last_modified) {
		this.last_modified = last_modified;
	}
	/**
	 * @return the comment
	 */
	public String getComment() {
		return this.comment;
	}
	/**
	 * @param comment the comment to set
	 */
	public void setComment(String comment) {
		this.comment = comment;
	}
	
	
}
