/**********************************************************************
 * Class TableURN
 * 
 * Copyright (c) 2010-2012, German National Library/Deutsche Nationalbibliothek
 * Adickesallee 1, D-60322 Frankfurt am Main, Federal Republic of Germany 
 *
 * This program is free software.
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 * Kadir Karaca Kocer -- German National Library
 * 
 **********************************************************************/

/* ********************************************************************
 * CHANGELOG:
 * 
 * 2012-03-15 Commented and ported to Apache Maven
 * Default values for all attributes (-1 for all numeric ones) 2011-04-08
 * Created on 2010-07-27 by Karaca Kocer
 ********************************************************************/

package org.nbnResolving.database.model;

import java.util.Date;

/**
 * A simple class modeling 1:1 the existing Sybase
 * RMDS table URN in epicur database.
 * For more information please see the database model.
 * 
 * @author Kadir Karaca Kocer
 */

public class TableURN {
	String   urn = null;
	long     urn_id = -1;           //Sybase intern generated id
	int      ns_id  = -1;           //foreign key
	long     parent = -1;           //foreign key
	long     newer_version = -1;    //foreign key
	long     older_version = -1;    //foreign key
	int      active        = -1;    //0: inactive, 1: active, 2: reserved
	String   idn = null;            //not important
	boolean  is_retrospective = false; //1: yes
	Date     created = new Date();     //date this record created. Default: NOW!
	Date     last_modified = new Date(); //date this record last modified
	String   comment = null;   //human readable comments about this record

	//some thoughts for future extensions
	int      input_way    = -1;             //1: OAI-PMH, 2:Web-Form ... etc.
	Date     last_checked = null;           //timestamp of last URL check
	Date     last_good    = null;           //timestamp of last successfull check
	TableINSTITUTION namespaceOwner = null; //which institution is responsible
	String   parentURN = null;              //Parent URN if any as String
	String   olderVersionURN  = null;       //older_version as String, not id
	
	/**
	 * Prints object state in a human friendly way
	 * @see java.lang.Object#toString()
	 */
	@Override
	public String toString() {
		String ret = "\nInformation about URN " + this.urn + "\n";
		ret = ret + "URN Id ..........: " + this.urn_id + "\n";
		ret = ret + "Namespace Id ....: " + this.ns_id + "\n";
		ret = ret + "Parent Id .......: " + this.parent + "\n";
		ret = ret + "Newer version ...: " + this.newer_version + "\n";
		ret = ret + "Older version ...: " + this.older_version + "\n";
		ret = ret + "Active ..........: " + this.active + "\n";
		ret = ret + "Retrospective ...: " + this.is_retrospective + "\n";
		ret = ret + "Created .........: " + this.created + "\n";
		ret = ret + "Last modified ...: " + this.last_modified + "\n";
		if (this.comment != null) {
			ret = ret + "Comments:\n\t" + this.comment + "\n";
		} else {
			ret = ret + "There are no comments saved for this URN\n";
		}
		if (this.namespaceOwner != null) {
			ret = ret + this.namespaceOwner.toString();
		} else {
			ret = ret + "Namespace owner is not saved for this URN\n";
		}
		
		return ret;
	}
	
	/**
	 * @return the urn
	 */
	public String getUrn() {
		return this.urn;
	}
	
	/**
	 * @param urn the urn to set
	 */
	public void setUrn(String urn) {
		this.urn = urn;
	}
	
	/**
	 * @return the urn_id
	 */
	public long getUrn_id() {
		return this.urn_id;
	}
	
	/**
	 * @param urn_id the urn_id to set
	 */
	public void setUrn_id(long urn_id) {
		this.urn_id = urn_id;
	}
	
	/**
	 * @return the ns_id
	 */
	public int getNs_id() {
		return this.ns_id;
	}
	
	/**
	 * @param ns_id the ns_id to set
	 */
	public void setNs_id(int ns_id) {
		this.ns_id = ns_id;
	}
	
	/**
	 * @return the parent
	 */
	public long getParent() {
		return this.parent;
	}
	
	/**
	 * @param parent the parent to set
	 */
	public void setParent(long parent) {
		this.parent = parent;
	}
	
	/**
	 * @return the newer_version
	 */
	public long getNewer_version() {
		return this.newer_version;
	}
	
	/**
	 * @param newer_version the newer_version to set
	 */
	public void setNewer_version(long newer_version) {
		this.newer_version = newer_version;
	}
	
	/**
	 * @return the older_version
	 */
	public long getOlder_version() {
		return this.older_version;
	}
	
	/**
	 * @param older_version the older_version to set
	 */
	public void setOlder_version(long older_version) {
		this.older_version = older_version;
	}
	
	/**
	 * @return the active
	 */
	public int getActive() {
		return this.active;
	}
	
	/**
	 * @param active the active to set
	 */
	public void setActive(int active) {
		this.active = active;
	}
	
	/**
	 * @return the idn
	 */
	public String getIdn() {
		return this.idn;
	}
	
	/**
	 * @param idn the idn to set
	 */
	public void setIdn(String idn) {
		this.idn = idn;
	}
	
	/**
	 * @return the is_retrospective
	 */
	public boolean isIs_retrospective() {
		return this.is_retrospective;
	}
	
	/**
	 * @param is_retrospective the is_retrospective to set
	 */
	public void setIs_retrospective(boolean is_retrospective) {
		this.is_retrospective = is_retrospective;
	}
	
	/**
	 * @return the created
	 */
	public Date getCreated() {
		return this.created;
	}
	
	/**
	 * @param created the created to set
	 */
	public void setCreated(Date created) {
		this.created = created;
	}
	
	/**
	 * @return the last_modified
	 */
	public Date getLast_modified() {
		return this.last_modified;
	}
	
	/**
	 * @param last_modified the last_modified to set
	 */
	public void setLast_modified(Date last_modified) {
		this.last_modified = last_modified;
	}
	
	/**
	 * @return the comment
	 */
	public String getComment() {
		return this.comment;
	}
	
	/**
	 * @param comment the comment to set
	 */
	public void setComment(String comment) {
		this.comment = comment;
	}
	
	/**
	 * @return the input_way
	 */
	public int getInput_way() {
		return this.input_way;
	}
	
	/**
	 * @param input_way the input_way to set
	 */
	public void setInput_way(int input_way) {
		this.input_way = input_way;
	}
	
	/**
	 * @return the last_checked
	 */
	public Date getLast_checked() {
		return this.last_checked;
	}
	
	/**
	 * @param last_checked the last_checked to set
	 */
	public void setLast_checked(Date last_checked) {
		this.last_checked = last_checked;
	}
	
	/**
	 * @return the last_good
	 */
	public Date getLast_good() {
		return this.last_good;
	}
	
	/**
	 * @param last_good the last_good to set
	 */
	public void setLast_good(Date last_good) {
		this.last_good = last_good;
	}
	
	/**
	 * @return the namespaceOwner
	 */
	public TableINSTITUTION getNamespaceOwner() {
		return this.namespaceOwner;
	}
	
	/**
	 * @param namespaceOwner the namespaceOwner to set
	 */
	public void setNamespaceOwner(TableINSTITUTION namespaceOwner) {
		this.namespaceOwner = namespaceOwner;
	}

	/**
	 * @return the parentURN
	 */
	public String getParentURN() {
		return this.parentURN;
	}

	/**
	 * @param parentURN the parentURN to set
	 */
	public void setParentURN(String parentURN) {
		this.parentURN = parentURN;
	}

	/**
	 * @return the olderVersionURN
	 */
	public String getOlderVersionURN() {
		return this.olderVersionURN;
	}

	/**
	 * @param olderVersionURN the olderVersionURN to set
	 */
	public void setOlderVersionURN(String olderVersionURN) {
		this.olderVersionURN = olderVersionURN;
	}
}
